==> org-lsst-sal-cccamera-2.5.0-sources.jar: org/lsst/sal/cccamera/event/Bonn_shutter_Device_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Bonn_shutter_Device_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double bonn_V36_warnHi;

  private final double bonn_V36_warnLo;

  private final double bonn_V36_limitHi;

  private final double bonn_V36_limitLo;

  private final double bonn_V5_warnHi;

  private final double bonn_V5_warnLo;

  private final double bonn_V5_limitHi;

  private final double bonn_V5_limitLo;

  public Bonn_shutter_Device_LimitsConfigurationEvent(int priority, String version,
      double bonn_V36_warnHi, double bonn_V36_warnLo, double bonn_V36_limitHi,
      double bonn_V36_limitLo, double bonn_V5_warnHi, double bonn_V5_warnLo, double bonn_V5_limitHi,
      double bonn_V5_limitLo) {
    super (priority);
    this.version = version;
    this.bonn_V36_warnHi = bonn_V36_warnHi;
    this.bonn_V36_warnLo = bonn_V36_warnLo;
    this.bonn_V36_limitHi = bonn_V36_limitHi;
    this.bonn_V36_limitLo = bonn_V36_limitLo;
    this.bonn_V5_warnHi = bonn_V5_warnHi;
    this.bonn_V5_warnLo = bonn_V5_warnLo;
    this.bonn_V5_limitHi = bonn_V5_limitHi;
    this.bonn_V5_limitLo = bonn_V5_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getBonn_V36_warnHi() {
    return bonn_V36_warnHi;
  }

  public double getBonn_V36_warnLo() {
    return bonn_V36_warnLo;
  }

  public double getBonn_V36_limitHi() {
    return bonn_V36_limitHi;
  }

  public double getBonn_V36_limitLo() {
    return bonn_V36_limitLo;
  }

  public double getBonn_V5_warnHi() {
    return bonn_V5_warnHi;
  }

  public double getBonn_V5_warnLo() {
    return bonn_V5_warnLo;
  }

  public double getBonn_V5_limitHi() {
    return bonn_V5_limitHi;
  }

  public double getBonn_V5_limitLo() {
    return bonn_V5_limitLo;
  }

  @Override
  public String toString() {
    return "Bonn_shutter_Device_LimitsConfigurationEvent{" + "version=" + version +
        ", bonn_V36_warnHi=" + bonn_V36_warnHi +", bonn_V36_warnLo=" + bonn_V36_warnLo +
        ", bonn_V36_limitHi=" + bonn_V36_limitHi +", bonn_V36_limitLo=" + bonn_V36_limitLo +
        ", bonn_V5_warnHi=" + bonn_V5_warnHi +", bonn_V5_warnLo=" + bonn_V5_warnLo +
        ", bonn_V5_limitHi=" + bonn_V5_limitHi +", bonn_V5_limitLo=" + bonn_V5_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double bonn_V36_warnHi;

    private double bonn_V36_warnLo;

    private double bonn_V36_limitHi;

    private double bonn_V36_limitLo;

    private double bonn_V5_warnHi;

    private double bonn_V5_warnLo;

    private double bonn_V5_limitHi;

    private double bonn_V5_limitLo;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder bonn_V36_warnHi(double bonn_V36_warnHi) {
      this.bonn_V36_warnHi = bonn_V36_warnHi;
      return this;
    }

    public Builder bonn_V36_warnLo(double bonn_V36_warnLo) {
      this.bonn_V36_warnLo = bonn_V36_warnLo;
      return this;
    }

    public Builder bonn_V36_limitHi(double bonn_V36_limitHi) {
      this.bonn_V36_limitHi = bonn_V36_limitHi;
      return this;
    }

    public Builder bonn_V36_limitLo(double bonn_V36_limitLo) {
      this.bonn_V36_limitLo = bonn_V36_limitLo;
      return this;
    }

    public Builder bonn_V5_warnHi(double bonn_V5_warnHi) {
      this.bonn_V5_warnHi = bonn_V5_warnHi;
      return this;
    }

    public Builder bonn_V5_warnLo(double bonn_V5_warnLo) {
      this.bonn_V5_warnLo = bonn_V5_warnLo;
      return this;
    }

    public Builder bonn_V5_limitHi(double bonn_V5_limitHi) {
      this.bonn_V5_limitHi = bonn_V5_limitHi;
      return this;
    }

    public Builder bonn_V5_limitLo(double bonn_V5_limitLo) {
      this.bonn_V5_limitLo = bonn_V5_limitLo;
      return this;
    }

    public Bonn_shutter_Device_LimitsConfigurationEvent build() {
      return new Bonn_shutter_Device_LimitsConfigurationEvent(priority, version, bonn_V36_warnHi, bonn_V36_warnLo, bonn_V36_limitHi, bonn_V36_limitLo, bonn_V5_warnHi, bonn_V5_warnLo, bonn_V5_limitHi, bonn_V5_limitLo);
    }
  }
}

==> org-lsst-sal-cccamera-2.5.8-sources.jar: org/lsst/sal/cccamera/event/Bonn_shutter_Device_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Bonn_shutter_Device_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double bonn_V36_warnHi;

  private final double bonn_V36_warnLo;

  private final double bonn_V36_limitHi;

  private final double bonn_V36_limitLo;

  private final double bonn_V5_warnHi;

  private final double bonn_V5_warnLo;

  private final double bonn_V5_limitHi;

  private final double bonn_V5_limitLo;

  public Bonn_shutter_Device_LimitsConfigurationEvent(String version, double bonn_V36_warnHi,
      double bonn_V36_warnLo, double bonn_V36_limitHi, double bonn_V36_limitLo,
      double bonn_V5_warnHi, double bonn_V5_warnLo, double bonn_V5_limitHi,
      double bonn_V5_limitLo) {
    this.version = version;
    this.bonn_V36_warnHi = bonn_V36_warnHi;
    this.bonn_V36_warnLo = bonn_V36_warnLo;
    this.bonn_V36_limitHi = bonn_V36_limitHi;
    this.bonn_V36_limitLo = bonn_V36_limitLo;
    this.bonn_V5_warnHi = bonn_V5_warnHi;
    this.bonn_V5_warnLo = bonn_V5_warnLo;
    this.bonn_V5_limitHi = bonn_V5_limitHi;
    this.bonn_V5_limitLo = bonn_V5_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getBonn_V36_warnHi() {
    return bonn_V36_warnHi;
  }

  public double getBonn_V36_warnLo() {
    return bonn_V36_warnLo;
  }

  public double getBonn_V36_limitHi() {
    return bonn_V36_limitHi;
  }

  public double getBonn_V36_limitLo() {
    return bonn_V36_limitLo;
  }

  public double getBonn_V5_warnHi() {
    return bonn_V5_warnHi;
  }

  public double getBonn_V5_warnLo() {
    return bonn_V5_warnLo;
  }

  public double getBonn_V5_limitHi() {
    return bonn_V5_limitHi;
  }

  public double getBonn_V5_limitLo() {
    return bonn_V5_limitLo;
  }

  @Override
  public String toString() {
    return "Bonn_shutter_Device_LimitsConfigurationEvent{" + "version=" + version +
        ", bonn_V36_warnHi=" + bonn_V36_warnHi +", bonn_V36_warnLo=" + bonn_V36_warnLo +
        ", bonn_V36_limitHi=" + bonn_V36_limitHi +", bonn_V36_limitLo=" + bonn_V36_limitLo +
        ", bonn_V5_warnHi=" + bonn_V5_warnHi +", bonn_V5_warnLo=" + bonn_V5_warnLo +
        ", bonn_V5_limitHi=" + bonn_V5_limitHi +", bonn_V5_limitLo=" + bonn_V5_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double bonn_V36_warnHi;

    private double bonn_V36_warnLo;

    private double bonn_V36_limitHi;

    private double bonn_V36_limitLo;

    private double bonn_V5_warnHi;

    private double bonn_V5_warnLo;

    private double bonn_V5_limitHi;

    private double bonn_V5_limitLo;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder bonn_V36_warnHi(double bonn_V36_warnHi) {
      this.bonn_V36_warnHi = bonn_V36_warnHi;
      return this;
    }

    public Builder bonn_V36_warnLo(double bonn_V36_warnLo) {
      this.bonn_V36_warnLo = bonn_V36_warnLo;
      return this;
    }

    public Builder bonn_V36_limitHi(double bonn_V36_limitHi) {
      this.bonn_V36_limitHi = bonn_V36_limitHi;
      return this;
    }

    public Builder bonn_V36_limitLo(double bonn_V36_limitLo) {
      this.bonn_V36_limitLo = bonn_V36_limitLo;
      return this;
    }

    public Builder bonn_V5_warnHi(double bonn_V5_warnHi) {
      this.bonn_V5_warnHi = bonn_V5_warnHi;
      return this;
    }

    public Builder bonn_V5_warnLo(double bonn_V5_warnLo) {
      this.bonn_V5_warnLo = bonn_V5_warnLo;
      return this;
    }

    public Builder bonn_V5_limitHi(double bonn_V5_limitHi) {
      this.bonn_V5_limitHi = bonn_V5_limitHi;
      return this;
    }

    public Builder bonn_V5_limitLo(double bonn_V5_limitLo) {
      this.bonn_V5_limitLo = bonn_V5_limitLo;
      return this;
    }

    public Bonn_shutter_Device_LimitsConfigurationEvent build() {
      return new Bonn_shutter_Device_LimitsConfigurationEvent(version, bonn_V36_warnHi, bonn_V36_warnLo, bonn_V36_limitHi, bonn_V36_limitLo, bonn_V5_warnHi, bonn_V5_warnLo, bonn_V5_limitHi, bonn_V5_limitLo);
    }
  }
}
